pub struct ListInit<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ListInit<'a>
impl<'a> ListInit<'a>
Sourcepub fn iter(self) -> ListIter<'a> ⓘ
pub fn iter(self) -> ListIter<'a> ⓘ
Returns an iterator over the elements of the list.
The iterator yields values of type TypedInit.
Sourcepub fn get(self, index: usize) -> Option<TypedInit<'a>>
pub fn get(self, index: usize) -> Option<TypedInit<'a>>
Returns the element at the given index in the list.
Sourcepub fn element_type(self) -> Option<Type>
pub fn element_type(self) -> Option<Type>
Returns the element type of this list, or None if it cannot be determined.